
## Models

NMMA will be under continuous development meaning that new astrophysical models such as for kilonovae, supernovae, gamma-ray bursts and so on will be implemented over time. Therefore, it is worthwhile to check out the `model_parameters_dict` in models.py from time to time.

### Kilonovae

These are optical counterparts to binary neutron star mergers generated by r-process material produced [(Metzger 2017)](https://arxiv.org/abs/1910.01617). In this framework, we use a [POSSIS](https://arxiv.org/abs/1906.04205)-based grid of kilonova models spanning the plausible binary neutron star parameter space [(Dietrich et al. 2020)](https://arxiv.org/abs/2002.11355>). There are four parameters:

* the dynamical ejecta $$M^{\rm dyn}_{\rm ej}$$
* disk wind ejecta $$M_{\rm ej}^{\mathrm{wind}}$$
* half opening angle $$\Phi$$
* observation angle $$\Theta_{\rm{obs}}$$

We make some of the most commonly used kilonova grid interpolated models available here: https://zenodo.org/record/8045280, which are automatically downloaded upon their first request.

### Gamma-ray burst afterglows

We use [afterglowpy](https://github.com/geoffryan/afterglowpy>) [(Ryan et al. 2020)](https://arxiv.org/abs/1909.11691), an open-source computational tool modeling forward shock synchrotron emission from relativistic blast waves as a function of jet structure and viewing angle. The model parameters are:

* isotropic kinetic energy $$E_{\mathrm{K,iso}}$$
* jet collimation angle $$\theta_c$$
* viewing angle $$\theta_v$$
* circumburst constant density $$n$$
* spectral slope of the electron distribution $$p$$
* fraction of energy imparted to the electrons by the shock $$\epsilon_e$$
* fraction of energy imparted to the magnetic field $$\epsilon_B$$

### Shock Cooling supernovae

We use a model from [Piro et al. 2021](https://arxiv.org/abs/2007.08543). Following shock breakout, the radiation of shock heated material expands and cools, known as shock cooling emission. The model has parameters:

* mass of extended material $$M_e$$
* radius of extended material $$R_e$$
* energy of material as the shock passes through it $$E_e$$

### Supernovae

We rely on a few different models for supernovae from [sncosmo](https://github.com/sncosmo/sncosmo). For example, the nugent-hyper model [(Levan et al. 2005)](https://arxiv.org/abs/astro-ph/0403450) used for SN Ib/c supernovae with the stretch and scale set to match the intrinsic (dereddened, rest frame) $R$-band luminosity of SN 1998bw at maximum light. The main free parameter is the absolute magnitude.
